## Treatment

A meta-analysis of tic treatment discusses patient satisfaction in addition to efficacy and side effects, and concludes that there is good evidence supporting a favorable benefits:harms ratio for the most commonly used medications, but that "larger and better-conducted trials addressing important clinical uncertainties are [still] required" \cite{26786936}.

### Psychological interventions

Behavior therapy is now an accepted first-line treatment for tic disorders. Still, some practitioners retain misconceptions about its safety. A report on 228 participants in randomized controlled trials (RCTs) of Comprehensive Behavioral Intervention for Tics (CBIT) helps to confute those concerns \cite{26763495}. Specifically, CBIT participants were no more likely to have new tics, have adverse events, increase tic medications or have an exacerbation in psychiatric symptoms relative to patients who received supportive therapy.

Factors that slow wider implementation of behavior therapies for tics include cost and a limited number of trained practitioners. Group (rather than individual) therapy is one option that could address these obstacles. A small study provided initial testing of this possibility using a treatment and a control group. Both groups had improvements in quality of life, and the greatest improvements in motor tic severity occurred in the HRT group \cite{27037483}. The most important conclusion from this pilot study was that the group format was acceptable and appears not to impair efficacy. 

Another potential solution to the implementation concerns noted above is providing therapy online. Müller-Vahl and colleagues are beginning a large RCT that will test the efficacy of CBIT delivered by internet \cite{27445874}. A commercial CBIT delivery system has been described, but (as of mid-2017) [is not yet active](http://www.tichelper.com/).

Research continues on other psychotherapy approaches. Suppressing tics is generally uncomfortable—leading to the theory of negative reinforcement that motivates CBIT and exposure and response prevention approaches to tic treatment—and in recent years Acceptance and Commitment Therapy for various conditions has become more popular, and pilot studies have appeared applying this approach to tics \cite{Franklin_2011,Reese_2015}. In this setting, \cite{Gev201678} report their study of 45 children and adolescents with TS who rated severity of tic urges, and were observed, during each of three 2-minute conditions: baseline (ticcing freely), tic suppression, and urge acceptance. Urges and discomfort decreased significantly during the acceptance condition, and more importantly, so did tic frequency. By contrast, tic urge intensity and self-rated discomfort increased during the tic suppression condition. These findings suggest that acceptance therapy may be better—accepted—by patients. It is now ripe for tests of long-term efficacy.

For some years, O'Connor, Leclerc and colleagues have developed and utilized a cognitive-behavioral-psychophysical treatment model for tic disorders. The treatment aims to address sensorimotor function more broadly, including proprioception, response inhibition and perfectionism, rather than focusing on tics directly. In 2016, several important publications from their group addressed this approach, including an open study of 102 adults with a chronic tic disorder (TS/CTD) \cite{26250742}, in which tic severity improved for both simple and complex tics, and continued improved at 6 months. Measures of self-esteem and perfectionism also improved. A pilot study in children ages 8-16 was also reported \cite{Leclerc2016}, followed by initial results with a manualized version of this therapy in children ages 8-12 \cite{27563292}. This "cognitive-psychophysiological treatment" model provides another potential approach to treatment that may prove to have more generalizable benefits.

### Medication

An open-label, rater-blind, 8-week study of deutetrabenazine in Tourette syndrome provided positive results \cite{27917309}. This compound is a deuterium-substituted tetrabenazine (a VMAT2 inhibitor) with slower elimination half-life, and was [approved by the U.S. Food and Drug Administration (FDA) in 2017](http://www.webcitation.org/6sOetNDv4) as a treatment for chorea in Huntington disease, making it potentially available for off-label use for tics. Similarly, another VMAT 2 inhibitor, valbenazine, was [approved in 2017 for treatment of tardive dyskinesia](http://www.webcitation.org/6sOfIOMua).

Adding to prior evidence of anti-tic efficacy, a prospective, open case series in 44 adults with TS found that aripiprazole helped non-tic symptoms as well as tics, though premonitory urges to tic were not significantly improved \cite{27672358}. However, in May, 2016, the FDA warned that aripiprazole can cause disinhibition in the form of impulse control disorders \cite{FDA:aripiprazole:ICDs}. Similar side effects have been described for levodopa and dopamine agonists, but had not been recognized for aripiprazole, which is a partial agonist at dopamine receptors.

Other medication trials reported in 2016 include a failed add-on RCT with N-acetyl-cysteine \cite{27027204} and a case series suggesting iron supplementation may improve tics in TS patients with low serum ferritin \cite{Ghosh:iron:abstract:2016}.

### Neurosurgery

Surgery is an option for carefully selected patients with TS, yet several important questions remain \cite{27548235}. The Milan, Italy, center provided a progress report on their large sample of TS patients treated with deep brain stimulation (DBS), mostly in the ventromedial thalamus \cite{26348012}. In 11 of 48 patients (23%), the device was removed after "inflammatory complications" or poor compliance with follow-up. In the remaining 37 patients, 29 had a more than 50% reduction in YGTSS scores (clinician-rated tic severity and impairment). In a separate publication, they argued that the patient's symptoms beyond tics should be considered when a DBS target is selected \cite{26739445}. Hartmann argued contrariwise that our current state of knowledge better supports a narrower focus on tic reduction in choosing a DBS target \cite{hartmann:2016:opinion}. 

The TS group from Maastricht, The Netherlands, reported positive unblinded follow-up results in 5 patients with refractory TS treated with DBS in the anterior globus pallidus pars interna (GPi) \cite{26811866}, and a Chinese group reported unblinded 1-year follow-up of GPi DBS in 24 patients with TS, with improvement, on average, in both tics and OCD symptoms (50% reduction in mean YGTSS total tic score and 27% reduction in mean Y-BOCS score) \cite{27098785}. Interestingly, this latter report includes one patient whose tics continued improved after the DBS electrode was removed (p. 1025), consistent either with spontaneous improvement over time or with a micropallidotomy lesion effect.

DBS in a mouse model suggests that self-injurious behaviors, probably over-represented in TS patients referred for surgery, may be amenable to DBS of the subthalamic nucleus \cite{26606849}.

Given the current lack of consensus on DBS methods in TS, gathering data on all DBS patient outcomes in TS is crucial, and a recent collaborative report described the establishment of the International Deep Brain Stimulation Registry and Database for Gilles de la Tourette syndrome \cite{27199634}. 

### Other treatment
Many patients have reported to their doctor that music performance reduces their tic symptoms. \citet{Brown:2016:thesis} addressed this formally, surveying 183 musicians diagnosed with TS. On a scale of 1 (drastic symptom worsening) to 5 (drastic symptom improvement), subjects reported a mean of 4.45 for the effect of engaging in a musical activity (performance, not passive listening). This result strongly supports the patient anecdotes and suggests that formal music therapy could be tested in a randomized controlled trial for benefit on TS symptoms. 

Some tic patients have been very interested in PANDAS, a name representing the hypothesis that obsessions, compulsions and tics represent an aberrant immune response to streptococcal infection in some children \cite{9733286}. Recently a second double-blind study of intravenous immunoglobulin (IVIG) for OCD symptoms in PANDAS patients was published \cite{27663941}. Unfortunately, although effects during the open label phase were substantial, there was little difference between the IVIG and control groups during the double-blind portion of the study.
